@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-from typing import Any, Type, Mapping, Literal, List
+from typing import Any, Type, Mapping, List
 
 from fastapi import FastAPI
 from pydantic import BaseModel, root_validator
 
+from patchwork.contrib.fastapi.tokens.utils import JWTConfig
 from patchwork.core.config import PublisherConfig
 from patchwork.core.typing import ClassPath
 
@@ -15,30 +16,6 @@ else:
     is_tortoise_installed = True
 
 
-class JWTConfig(BaseModel):
-    """
-    JWT configuration
-
-    :cvar secret:
-        A secret key for JWT encryption
-    """
-    secret: str
-    algorithm: str = "HS256"
-    allowed_issuer: List[str] = None
-    allowed_audience: str = None
-
-    # following settings must be set to generate JWT access tokens
-    cookie_name: str = 'access_token'
-    path: str = '/'
-    https_only: bool = True
-    samesite: Literal['lax', 'strict', 'none'] = 'strict'
-    # note: it's None just to work if generation is not used, however to generate cookie it must be set
-    domain: str = None
-    validity: int = None
-    issuer: str = None
-    audience: List[str] = None
-
-
 class PatchworkFastAPISettings(BaseModel):
     """
     Settings for FastAPI and Patchwork integration
@@ -53,7 +30,7 @@ class PatchworkFastAPISettings(BaseModel):
 
     publisher: PublisherConfig = None
 
-    jwt: JWTConfig = None
+    jwt: List[JWTConfig] = None
 
     if is_tortoise_installed:
         user_model: ClassPath[Type[models.Model]] = None
@@ -78,13 +55,13 @@ def register_patchwork(app: FastAPI, api_settings: Mapping):
     settings = api_settings
 
     if settings.publisher is not None:
-        from patchwork.contrib.fastapi import get_publisher
+        from patchwork.contrib.fastapi.dependencies import get_publisher
         publisher = get_publisher()
         app.on_event('startup')(publisher.run)
         app.on_event('shutdown')(publisher.terminate)
 
     if settings.jwt is not None:
-        from patchwork.contrib.fastapi.jwt import AccessTokenMiddleware
+        from patchwork.contrib.fastapi.tokens.middleware import AccessTokenMiddleware
         app.add_middleware(
             AccessTokenMiddleware,
             config=settings.jwt
