@@ -39,7 +39,7 @@ class AccessTokenMiddleware:
         elif token.is_modified:
             header_value = f"{token.config.cookie_name}={token.get()}; " \
                            f"path={token.config.path}; " \
-                           f"max-age={min(int(token.exp - unix_now()), 0)}; " \
+                           f"max-age={max(int(token.exp - unix_now()), 0)}; " \
                            f"httponly; " \
                            f"{'secure; ' if token.config.https_only else ''}" \
                            f"samesite={token.config.samesite.lower()}; " \
